==> Alfred-Workflow-1.10.0.tar.gz: Alfred-Workflow-1.10.0/workflow/__init__.py <==
#!/usr/bin/env python
# encoding: utf-8
#
# Copyright (c) 2014 Dean Jackson <deanishe@deanishe.net>
#
# MIT Licence. See http://opensource.org/licenses/MIT
#
# Created on 2014-02-15
#

"""
A Python helper library for `Alfred 2 <http://www.alfredapp.com/>`_ Workflow
authors.
"""

import os

__title__ = 'Alfred-Workflow'
__version__ = open(os.path.join(os.path.dirname(__file__), 'version')).read()
__author__ = 'Dean Jackson'
__licence__ = 'MIT'
__copyright__ = 'Copyright 2014 Dean Jackson'


# Workflow objects
from .workflow import Workflow, manager

# Exceptions
from .workflow import PasswordNotFound, KeychainError

# Icons
from .workflow import (
    ICON_ACCOUNT,
    ICON_BURN,
    ICON_CLOCK,
    ICON_COLOR,
    ICON_COLOUR,
    ICON_EJECT,
    ICON_ERROR,
    ICON_FAVORITE,
    ICON_FAVOURITE,
    ICON_GROUP,
    ICON_HELP,
    ICON_HOME,
    ICON_INFO,
    ICON_NETWORK,
    ICON_NOTE,
    ICON_SETTINGS,
    ICON_SWIRL,
    ICON_SWITCH,
    ICON_SYNC,
    ICON_TRASH,
    ICON_USER,
    ICON_WARNING,
    ICON_WEB,
)

# Filter matching rules
from .workflow import (
    MATCH_ALL,
    MATCH_ALLCHARS,
    MATCH_ATOM,
    MATCH_CAPITALS,
    MATCH_INITIALS,
    MATCH_INITIALS_CONTAIN,
    MATCH_INITIALS_STARTSWITH,
    MATCH_STARTSWITH,
    MATCH_SUBSTRING,
)

__all__ = [
    Workflow,
    manager,
    PasswordNotFound,
    KeychainError,
    ICON_ACCOUNT,
    ICON_BURN,
    ICON_CLOCK,
    ICON_COLOR,
    ICON_COLOUR,
    ICON_EJECT,
    ICON_ERROR,
    ICON_FAVORITE,
    ICON_FAVOURITE,
    ICON_GROUP,
    ICON_HELP,
    ICON_HOME,
    ICON_INFO,
    ICON_NETWORK,
    ICON_NOTE,
    ICON_SETTINGS,
    ICON_SWIRL,
    ICON_SWITCH,
    ICON_SYNC,
    ICON_TRASH,
    ICON_USER,
    ICON_WARNING,
    ICON_WEB,
    MATCH_ALL,
    MATCH_ALLCHARS,
    MATCH_ATOM,
    MATCH_CAPITALS,
    MATCH_INITIALS,
    MATCH_INITIALS_CONTAIN,
    MATCH_INITIALS_STARTSWITH,
    MATCH_STARTSWITH,
    MATCH_SUBSTRING,
]

==> Alfred-Workflow-1.11.0.tar.gz: Alfred-Workflow-1.11.0/workflow/__init__.py <==
#!/usr/bin/env python
# encoding: utf-8
#
# Copyright (c) 2014 Dean Jackson <deanishe@deanishe.net>
#
# MIT Licence. See http://opensource.org/licenses/MIT
#
# Created on 2014-02-15
#

"""
A Python helper library for `Alfred 2 <http://www.alfredapp.com/>`_ Workflow
authors.
"""

import os

__title__ = 'Alfred-Workflow'
__version__ = open(os.path.join(os.path.dirname(__file__), 'version')).read()
__author__ = 'Dean Jackson'
__licence__ = 'MIT'
__copyright__ = 'Copyright 2014 Dean Jackson'


# Workflow objects
from .workflow import Workflow, manager

# Exceptions
from .workflow import PasswordNotFound, KeychainError

# Icons
from .workflow import (
    ICON_ACCOUNT,
    ICON_BURN,
    ICON_CLOCK,
    ICON_COLOR,
    ICON_COLOUR,
    ICON_EJECT,
    ICON_ERROR,
    ICON_FAVORITE,
    ICON_FAVOURITE,
    ICON_GROUP,
    ICON_HELP,
    ICON_HOME,
    ICON_INFO,
    ICON_NETWORK,
    ICON_NOTE,
    ICON_SETTINGS,
    ICON_SWIRL,
    ICON_SWITCH,
    ICON_SYNC,
    ICON_TRASH,
    ICON_USER,
    ICON_WARNING,
    ICON_WEB,
)

# Filter matching rules
from .workflow import (
    MATCH_ALL,
    MATCH_ALLCHARS,
    MATCH_ATOM,
    MATCH_CAPITALS,
    MATCH_INITIALS,
    MATCH_INITIALS_CONTAIN,
    MATCH_INITIALS_STARTSWITH,
    MATCH_STARTSWITH,
    MATCH_SUBSTRING,
)

__all__ = [
    'Workflow',
    'manager',
    'PasswordNotFound',
    'KeychainError',
    'ICON_ACCOUNT',
    'ICON_BURN',
    'ICON_CLOCK',
    'ICON_COLOR',
    'ICON_COLOUR',
    'ICON_EJECT',
    'ICON_ERROR',
    'ICON_FAVORITE',
    'ICON_FAVOURITE',
    'ICON_GROUP',
    'ICON_HELP',
    'ICON_HOME',
    'ICON_INFO',
    'ICON_NETWORK',
    'ICON_NOTE',
    'ICON_SETTINGS',
    'ICON_SWIRL',
    'ICON_SWITCH',
    'ICON_SYNC',
    'ICON_TRASH',
    'ICON_USER',
    'ICON_WARNING',
    'ICON_WEB',
    'MATCH_ALL',
    'MATCH_ALLCHARS',
    'MATCH_ATOM',
    'MATCH_CAPITALS',
    'MATCH_INITIALS',
    'MATCH_INITIALS_CONTAIN',
    'MATCH_INITIALS_STARTSWITH',
    'MATCH_STARTSWITH',
    'MATCH_SUBSTRING',
]
